@@ -18,16 +18,16 @@ function (coordinates, path.mcmc, printit = FALSE, path)
         image(seq(min(coordinates[, 1] - delta.coord/2), max(coordinates[, 
             1] + delta.coord/2), length = nxdom), seq(min(coordinates[, 
             2] - delta.coord/2), max(coordinates[, 2] + delta.coord/2), 
-            length = nydom), matrix(dom.post[, iclass], nr = nxdom, 
-            nc = nydom, byrow = TRUE), xlab = "x coordinates", 
+            length = nydom), matrix(dom.post[, iclass], nrow = nxdom, 
+            ncol = nydom, byrow = TRUE), xlab = "x coordinates", 
             ylab = "y coordinates", asp = 1)
         title(main = paste("Map of posterior probability to belong to cluster ", 
             iclass))
         contour(seq(min(coordinates[, 1] - delta.coord/2), max(coordinates[, 
             1] + delta.coord/2), length = nxdom), seq(min(coordinates[, 
             2] - delta.coord/2), max(coordinates[, 2] + delta.coord/2), 
-            length = nydom), matrix(dom.post[, iclass], nr = nxdom, 
-            nc = nydom, byrow = TRUE), add = TRUE)
+            length = nydom), matrix(dom.post[, iclass], nrow = nxdom, 
+            ncol = nydom, byrow = TRUE), add = TRUE)
         points(coordinates[, 1], coordinates[, 2], pch = 16)
         if (printit == TRUE) {
             postscript(file = paste(path, "/mapproba.pop", iclass, 
@@ -36,7 +36,7 @@ function (coordinates, path.mcmc, printit = FALSE, path)
                 max(coordinates[, 1] + delta.coord/2), length = nxdom), 
                 seq(min(coordinates[, 2] - delta.coord/2), max(coordinates[, 
                   2] + delta.coord/2), length = nydom), matrix(dom.post[, 
-                  iclass], nr = nxdom, nc = nydom, byrow = TRUE), 
+                  iclass], nrow = nxdom, ncol = nydom, byrow = TRUE), 
                 xlab = "x coordinates", ylab = "y coordinates", 
                 asp = 1)
             title(main = paste("Map of posterior probability to belong to cluster ", 
@@ -45,7 +45,7 @@ function (coordinates, path.mcmc, printit = FALSE, path)
                 max(coordinates[, 1] + delta.coord/2), length = nxdom), 
                 seq(min(coordinates[, 2] - delta.coord/2), max(coordinates[, 
                   2] + delta.coord/2), length = nydom), matrix(dom.post[, 
-                  iclass], nr = nxdom, nc = nydom, byrow = TRUE), 
+                  iclass], nrow = nxdom, ncol = nydom, byrow = TRUE), 
                 add = TRUE)
             points(coordinates[, 1], coordinates[, 2], pch = 16)
             dev.off()
